Learn R Programming

betaDelta (version 1.0.6)

confint.betadelta: Confidence Intervals for Standardized Regression Slopes

Description

Confidence Intervals for Standardized Regression Slopes

Usage

# S3 method for betadelta
confint(object, parm = NULL, level = 0.95, ...)

Value

Returns a matrix of confidence intervals.

Arguments

object

Object of class betadelta.

parm

a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.

level

the confidence level required.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan

Examples

Run this code
object <- lm(QUALITY ~ NARTIC + PCTGRT + PCTSUPP, data = nas1982)
std <- BetaDelta(object)
confint(std, level = 0.95)

Run the code above in your browser using DataLab