Learn R Programming

betaDelta (version 1.0.6)

confint.deltamethod: Confidence Intervals

Description

Confidence Intervals

Usage

# S3 method for deltamethod
confint(object, parm = NULL, level = 0.95, ...)

Value

Returns a matrix of confidence intervals.

Arguments

object

Object of class deltamethod.

parm

a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.

level

the confidence level required.

...

additional arguments.

Author

Ivan Jacob Agaloos Pesigan

Examples

Run this code
object <- glm(
  formula = vs ~ wt + disp,
  family = "binomial",
  data = mtcars
)
def <- list("exp(wt)", "exp(disp)")
out <- DeltaGeneric(
  object = object,
  def = def,
  alpha = 0.05
)
confint(out, level = 0.95)

Run the code above in your browser using DataLab